@@ -1,22 +1,26 @@
 /*
  *  connect.c
  *
- *  $Id: connect.c,v 1.40 2005/11/04 13:08:54 source Exp $
+ *  $Id: connect.c,v 1.44 2006/01/24 00:09:25 source Exp $
  *
  *  Connect (load) driver
  *
  *  The iODBC driver manager.
- *  
- *  Copyright (C) 1995 by Ke Jin <kejin@empress.com> 
- *  Copyright (C) 1996-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *
+ *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -29,8 +33,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,7 +43,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -71,6 +75,7 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
 #include <iodbc.h>
 
 #include <sql.h>
@@ -398,7 +403,7 @@ _iodbcdm_driverload (
   HPROC hproc;
   SQLRETURN retcode = SQL_SUCCESS;
   sqlstcode_t sqlstat = en_00000;
-  char *driverbuf[1024];
+  char driverbuf[1024];
 
   if (path == NULL || ((char *) path)[0] == '\0')
     {
@@ -1203,6 +1208,7 @@ SQLConnect (
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLConnectA (
   SQLHDBC		  hdbc,
@@ -1265,6 +1271,7 @@ SQLConnectW (SQLHDBC hdbc,
 	szUID, cbUID,
 	szAuthStr, cbAuthStr));
 }
+#endif
 
 
 SQLRETURN SQL_API
@@ -1281,7 +1288,7 @@ SQLDriverConnect_Internal (
 {
   CONN (pdbc, hdbc);
   ENVR (penv, NULL);
-  HDLL hdll;
+  HDLL hdll = NULL;
   void *drv;
   SQLWCHAR drvbuf[1024];
   void *dsn;
@@ -1719,6 +1726,7 @@ SQLDriverConnect (SQLHDBC hdbc,
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLDriverConnectA (SQLHDBC hdbc,
     SQLHWND hwnd,
@@ -1789,6 +1797,7 @@ SQLDriverConnectW (SQLHDBC hdbc,
 	szConnStrOut, cbConnStrOutMax, pcbConnStrOut,
 	fDriverCompletion));
 }
+#endif
 
 
 SQLRETURN SQL_API
@@ -2044,6 +2053,7 @@ SQLBrowseConnect (SQLHDBC hdbc,
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLBrowseConnectA (SQLHDBC hdbc,
     SQLCHAR * szConnStrIn,
@@ -2098,6 +2108,7 @@ SQLBrowseConnectW (SQLHDBC hdbc,
 	szConnStrIn, cbConnStrIn,
 	szConnStrOut, cbConnStrOutMax, pcbConnStrOut));
 }
+#endif
 
 
 static SQLRETURN
@@ -2335,6 +2346,7 @@ SQLNativeSql (
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLNativeSqlA (
     SQLHDBC hdbc,
@@ -2391,3 +2403,4 @@ SQLNativeSqlW (
 	szSqlStrIn, cbSqlStrIn,
 	szSqlStr, cbSqlStrMax, pcbSqlStr));
 }
+#endif
