@@ -1,22 +1,26 @@
 /*
  *  hstmt.c
  *
- *  $Id: hstmt.c,v 1.23 2004/07/06 15:26:07 source Exp $
+ *  $Id: hstmt.c,v 1.25 2006/01/20 15:58:34 source Exp $
  *
  *  Query statement object management functions
  *
  *  The iODBC driver manager.
- *  
- *  Copyright (C) 1995 by Ke Jin <kejin@empress.com> 
- *  Copyright (C) 1996-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *
+ *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -29,8 +33,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,7 +43,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -71,6 +75,7 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
 #include <iodbc.h>
 
 #include <sql.h>
@@ -802,6 +807,7 @@ SQLSetStmtOption (
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API 
 SQLSetStmtOptionA (
   SQLHSTMT		  hstmt,
@@ -816,6 +822,7 @@ SQLSetStmtOptionA (
   LEAVE_STMT (hstmt,
     trace_SQLSetStmtOption (TRACE_LEAVE, hstmt, fOption, vParam));
 }
+#endif
 
 
 SQLRETURN
@@ -963,6 +970,7 @@ SQLGetStmtOption (
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API 
 SQLGetStmtOptionA (
     SQLHSTMT hstmt,
@@ -977,6 +985,7 @@ SQLGetStmtOptionA (
   LEAVE_STMT (hstmt,
     trace_SQLGetStmtOption (TRACE_LEAVE, hstmt, fOption, pvParam));
 }
+#endif
 
 
 static SQLRETURN 
