@@ -1,22 +1,26 @@
 /*
  *  info.c
  *
- *  $Id: info.c,v 1.30 2005/05/12 12:27:15 source Exp $
+ *  $Id: info.c,v 1.32 2006/01/20 15:58:34 source Exp $
  *
  *  Information functions
  *
  *  The iODBC driver manager.
- *  
- *  Copyright (C) 1995 by Ke Jin <kejin@empress.com> 
- *  Copyright (C) 1996-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *
+ *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -29,8 +33,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,7 +43,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -71,6 +75,7 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
 #include <iodbc.h>
 
 #include <sql.h>
@@ -316,6 +321,7 @@ SQLDataSources (
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLDataSourcesA (
   SQLHENV		  henv,
@@ -412,6 +418,7 @@ SQLDataSourcesW (
 	szDSN, cbDSNMax, pcbDSN,
 	szDesc, cbDescMax, pcbDesc));
 }
+#endif
 
 
 SQLRETURN SQL_API
@@ -603,6 +610,7 @@ SQLDrivers (
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLDriversA (
   SQLHENV		  henv,
@@ -698,6 +706,7 @@ SQLDriversW (SQLHENV henv,
 	szDrvDesc, cbDrvDescMax, pcbDrvDesc, 
 	szDrvAttr, cbDrvAttrMax, pcbDrvAttr));
 }
+#endif
 
 
 SQLRETURN SQL_API
@@ -1115,6 +1124,7 @@ SQLGetInfo (SQLHDBC hdbc,
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLGetInfoA (SQLHDBC hdbc,
   SQLUSMALLINT		  fInfoType,
@@ -1168,6 +1178,7 @@ SQLGetInfoW (
 	fInfoType, 
 	rgbInfoValue, cbInfoValueMax, pcbInfoValue));
 }
+#endif
 
 
 static int FunctionNumbers[] =
