@@ -1,22 +1,26 @@
 /*
  *  result.c
  *
- *  $Id: result.c,v 1.21 2004/07/06 15:26:07 source Exp $
+ *  $Id: result.c,v 1.23 2006/01/20 15:58:35 source Exp $
  *
  *  Prepare for getting query result
  *
  *  The iODBC driver manager.
- *  
- *  Copyright (C) 1995 by Ke Jin <kejin@empress.com> 
- *  Copyright (C) 1996-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *
+ *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -29,8 +33,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,7 +43,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -366,6 +370,7 @@ SQLGetCursorName (
 }
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLGetCursorNameA (
   SQLHSTMT 		  hstmt,
@@ -411,6 +416,7 @@ SQLGetCursorNameW (SQLHSTMT hstmt,
     	hstmt,
 	szCursor, cbCursorMax, pcbCursor));
 }
+#endif
 
 
 static SQLRETURN 
@@ -818,6 +824,7 @@ SQLDescribeCol (SQLHSTMT hstmt,
 } 
 
 
+#if ODBCVER >= 0x0300
 SQLRETURN SQL_API
 SQLDescribeColA (SQLHSTMT hstmt,
     SQLUSMALLINT	  icol,
@@ -903,6 +910,7 @@ SQLDescribeColW (
 	pibScale,
 	pfNullable));
 }
+#endif
 
 
 SQLRETURN SQL_API
@@ -1227,6 +1235,7 @@ SQLColAttributes (
 }
 
 
+#if ODBCVER >= 0x0300
 RETCODE SQL_API
 SQLColAttributesA (
   SQLHSTMT 		  statementHandle,
@@ -1297,3 +1306,4 @@ SQLColAttributesW (
 	rgbDesc, cbDescMax, pcbDesc, 
 	pfDesc));
 }
+#endif
