@@ -1,21 +1,25 @@
 /*
  *  Info.c
  *
- *  $Id: Info.c,v 1.5 2005/08/30 12:59:02 source Exp $
+ *  $Id: Info.c,v 1.7 2006/01/20 15:58:35 source Exp $
  *
  *  Decode the SQLGetInfo responses and dump them to the trace log
  *
  *  The iODBC driver manager.
- *  
- *  Copyright (C) 1996-2003 by OpenLink Software <iodbc@openlinksw.com>
+ *
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -28,8 +32,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,7 +42,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -69,6 +73,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
 #include "trace.h"
 
 
@@ -1731,7 +1736,7 @@ print_mask:
   trace_emit ("\t\t%-15.15s   %d (%s)\n",
   	"SQLUSMALLINT", fInfoType, infoname);
   trace_emit ("\t\t%-15.15s   %p (0x%lX)\n",
-	"SQLPOINTER", rgbInfoValue, 
+	"SQLPOINTER", rgbInfoValue,
 	(unsigned long) *((unsigned int *) rgbInfoValue));
 
   if (*(int *) rgbInfoValue == 0)
@@ -1786,13 +1791,14 @@ trace_SQLGetInfo (int trace_leave, int retcode,
 
   /* Trace Arguments */
   _trace_handle (SQL_HANDLE_DBC, hdbc);
-  _trace_getinfo (fInfoType, rgbInfoValue, cbInfoValueMax, pcbInfoValue, 
+  _trace_getinfo (fInfoType, rgbInfoValue, cbInfoValueMax, pcbInfoValue,
   	TRACE_OUTPUT_SUCCESS, 'A');
   _trace_smallint (cbInfoValueMax);
   _trace_smallint_p (pcbInfoValue, TRACE_OUTPUT_SUCCESS);
 }
 
 
+#if ODBCVER >= 0x0300
 void
 trace_SQLGetInfoW (int trace_leave, int retcode,
   SQLHDBC		  hdbc,
@@ -1811,3 +1817,4 @@ trace_SQLGetInfoW (int trace_leave, int retcode,
   _trace_smallint (cbInfoValueMax);
   _trace_smallint_p (pcbInfoValue, TRACE_OUTPUT_SUCCESS);
 }
+#endif
