@@ -1,13 +1,13 @@
 /*
  *  trace.c
  *
- *  $Id: trace.c,v 1.15 2005/10/08 15:13:03 source Exp $
+ *  $Id: trace.c,v 1.18 2006/01/24 00:09:25 source Exp $
  *
  *  Trace functions
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1996-2003 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -16,6 +16,10 @@
  *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -28,8 +32,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,7 +42,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -70,6 +74,7 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -391,7 +396,7 @@ trace_start(void)
   }
 #else
   {
-    trace_set_appname (getprogname());
+    trace_set_appname ((char *) getprogname ());
   }
 #endif
 #endif
@@ -651,12 +656,13 @@ _trace_print_function (int func, int trace_leave, int retcode)
 {
   extern char *odbcapi_symtab[];
   char *ptr = "invalid retcode";
-  struct timeval tv;
 
   /*
    * Calculate timestamp
    */
 #ifdef HAVE_GETTIMEOFDAY
+  struct timeval tv;
+
   gettimeofday (&tv, NULL);
   tv.tv_sec -= starttime.tv_sec;
   tv.tv_usec -= starttime.tv_usec;
@@ -715,8 +721,10 @@ _trace_handletype (SQLSMALLINT type)
       _S (SQL_HANDLE_ENV);
       _S (SQL_HANDLE_DBC);
       _S (SQL_HANDLE_STMT);
+#if ODBCVER >= 0x0300
       _S (SQL_HANDLE_DESC);
       _S (SQL_HANDLE_SENV);
+#endif
     }
 
   trace_emit ("\t\t%-15.15s   %d (%s)\n", "SQLSMALLINT", (int) type, ptr);
@@ -998,6 +1006,7 @@ _trace_c_type (SQLSMALLINT type)
 #if (ODBCVER >= 0x0350)
       _S (SQL_C_GUID);
 #endif
+#if ODBCVER >= 0x0300
       _S (SQL_C_INTERVAL_DAY);
       _S (SQL_C_INTERVAL_DAY_TO_HOUR);
       _S (SQL_C_INTERVAL_DAY_TO_MINUTE);
@@ -1011,9 +1020,12 @@ _trace_c_type (SQLSMALLINT type)
       _S (SQL_C_INTERVAL_SECOND);
       _S (SQL_C_INTERVAL_YEAR);
       _S (SQL_C_INTERVAL_YEAR_TO_MONTH);
+#endif
       _S (SQL_C_LONG);
+#if ODBCVER >= 0x0300
       _S (SQL_C_NUMERIC);
       _S (SQL_C_SBIGINT);
+#endif
       _S (SQL_C_SHORT);
       _S (SQL_C_SLONG);
       _S (SQL_C_SSHORT);
@@ -1021,17 +1033,21 @@ _trace_c_type (SQLSMALLINT type)
       _S (SQL_C_TIME);
       _S (SQL_C_TIMESTAMP);
       _S (SQL_C_TINYINT);
+#if ODBCVER >= 0x0300
       _S (SQL_C_TYPE_DATE);
       _S (SQL_C_TYPE_TIME);
       _S (SQL_C_TYPE_TIMESTAMP);
       _S (SQL_C_UBIGINT);
+#endif
       _S (SQL_C_ULONG);
       _S (SQL_C_USHORT);
       _S (SQL_C_UTINYINT);
       /* _S (SQL_C_VARBOOKMARK); */
       _S (SQL_C_WCHAR);
 
+#if ODBCVER >= 0x0300
       _S (SQL_ARD_TYPE);
+#endif
     }
 
   trace_emit ("\t\t%-15.15s   %d (%s)\n", "SQLSMALLINT ", type, ptr);
@@ -1090,9 +1106,11 @@ _trace_sql_type (SQLSMALLINT type)
 #endif
       _S (SQL_TIMESTAMP);
       _S (SQL_TINYINT);
+#if ODBCVER >= 0x0300
       _S (SQL_TYPE_DATE);
       _S (SQL_TYPE_TIME);
       _S (SQL_TYPE_TIMESTAMP);
+#endif
       _S (SQL_VARBINARY);
       _S (SQL_VARCHAR);
       _S (SQL_WCHAR);
@@ -1153,9 +1171,11 @@ _trace_sql_type_p (SQLSMALLINT *p, int output)
 #endif
       _S (SQL_TIMESTAMP);
       _S (SQL_TINYINT);
+#if ODBCVER >= 0x0300
       _S (SQL_TYPE_DATE);
       _S (SQL_TYPE_TIME);
       _S (SQL_TYPE_TIMESTAMP);
+#endif
       _S (SQL_VARBINARY);
       _S (SQL_VARCHAR);
       _S (SQL_WCHAR);
@@ -1167,6 +1187,7 @@ _trace_sql_type_p (SQLSMALLINT *p, int output)
 }
 
 
+#if ODBCVER >= 0x0300
 void
 _trace_sql_subtype (SQLSMALLINT *type, SQLSMALLINT *sub, int output)
 {
@@ -1218,6 +1239,7 @@ _trace_sql_subtype (SQLSMALLINT *type, SQLSMALLINT *sub, int output)
   else
     trace_emit ("\t\t%-15.15s * %p (%d)\n", "SQLSMALLINT", sub, *sub);
 }
+#endif
 
 
 void
@@ -1229,11 +1251,13 @@ _trace_bufferlen (SQLINTEGER length)
   switch (length)
    {
 	_S (SQL_NTS);
+#if ODBCVER >= 0x0300
 	_S (SQL_IS_POINTER);
 	_S (SQL_IS_UINTEGER);
 	_S (SQL_IS_INTEGER);
 	_S (SQL_IS_USMALLINT);
 	_S (SQL_IS_SMALLINT);
+#endif
    }
 
   /*
