@@ -1,11 +1,11 @@
 /*
  *  confirm.c
  *
- *  $Id: confirm.c,v 1.3 2004/06/22 11:25:48 source Exp $
+ *  $Id: confirm.c,v 1.2 2006/01/20 15:58:35 source Exp $
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -14,6 +14,10 @@
  *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -26,8 +30,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +40,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -68,6 +72,9 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
+#include <odbcinst.h>
+#include <unicode.h>
 #include "gui.h"
 #include "question.xpm"
 
@@ -234,3 +241,20 @@ create_confirm (HWND hwnd, LPCSTR dsn, LPCSTR text)
 
   return confirm_t.yes_no;
 }
+
+BOOL
+create_confirmw (HWND hwnd, LPCWSTR dsn, LPCWSTR text)
+{
+  LPSTR _dsn = NULL;
+  LPSTR _text = NULL;
+
+  _dsn = dm_SQL_WtoU8(dsn, SQL_NTS);
+  _text = dm_SQL_WtoU8(text, SQL_NTS);
+
+  create_message(hwnd, _dsn, _text);
+
+  if (_dsn)
+    free(_dsn);
+  if (_text)
+    free(_text);
+}
