@@ -1,22 +1,26 @@
 /*
  *  dlf.c
  *
- *  $Id: dlf.c,v 1.17 2004/06/18 23:53:48 source Exp $
+ *  $Id: dlf.c,v 1.3 2006/01/24 00:08:54 source Exp $
  *
  *  Dynamic Library Loader (mapping to SVR4)
  *
  *  The iODBC driver manager.
- *  
- *  Copyright (C) 1995 by Ke Jin <kejin@empress.com> 
- *  Copyright (C) 1996-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *
+ *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
  *  licenses:
  *
- *      - GNU Library General Public License (see LICENSE.LGPL) 
+ *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -29,8 +33,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,7 +43,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -71,6 +75,20 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 #include <dlf.h>
 #include <errno.h>
 
@@ -995,26 +1013,23 @@ dlclose (void *hdll)
  *********************************/
 #ifdef	DLDAPI_MACX
 static struct dlopen_handle *dlopen_handles = NULL;
-static const struct dlopen_handle main_program_handle = { NULL };
+static const struct dlopen_handle main_program_handle = { 0 };
 static char *dlerror_pointer = NULL;
 
-  enum bool
-  { false, true };
-
 /*
  * NSMakePrivateModulePublic() is not part of the public dyld API so we define
  * it here.  The internal dyld function pointer for
  * __dyld_NSMakePrivateModulePublic is returned so thats all that matters to get
  * the functionality need to implement the dlopen() interfaces.
  */
-static enum bool
+static int
 NSMakePrivateModulePublic (NSModule module)
 {
-  static enum bool (*p) (NSModule module) = NULL;
+  static int (*p) (NSModule module) = NULL;
 
   if (p == NULL)
     _dyld_func_lookup ("__dyld_NSMakePrivateModulePublic",
-	(unsigned long *) &p);
+	(void *) &p);
   if (p == NULL)
     {
 #ifdef DEBUG
@@ -1031,7 +1046,7 @@ NSMakePrivateModulePublic (NSModule module)
  * dlopen() the MacOS X version of the FreeBSD dlopen() interface.
  */
 void *
-dlopen (char * path, int mode)
+iodbc_dlopen (char * path, int mode)
 {
   void *retval;
   struct stat stat_buf;
@@ -1042,6 +1057,7 @@ dlopen (char * path, int mode)
   unsigned long options;
   NSSymbol NSSymbol;
   void (*init) (void);
+  static char errbuf[640];
 
   dlerror_pointer = NULL;
 
@@ -1156,7 +1172,14 @@ dlopen (char * path, int mode)
   NSDestroyObjectFileImage (objectFileImage);
   if (module == NULL)
     {
-      dlerror_pointer = "NSLinkModule() failed for dlopen()";
+      NSLinkEditErrors lerr;
+      int errNum;
+      const char *fname;
+      const char *errStr;
+      NSLinkEditError(&lerr, &errNum, &fname, &errStr);
+      sprintf(errbuf, "NSLinkModule() failed for dlopen() ([%.256s][%.256s])",
+      		fname, errStr);
+      dlerror_pointer = errbuf;
       return (NULL);
     }
 
@@ -1214,7 +1237,7 @@ dlopen (char * path, int mode)
  * dlsym() the MacOS X version of the FreeBSD dlopen() interface.
  */
 void *
-dlsym (void * handle, char * symbol)
+iodbc_dlsym (void * handle, char * symbol)
 {
   struct dlopen_handle *dlopen_handle, *p;
   char symbol2[1024];
@@ -1278,7 +1301,7 @@ dlsym (void * handle, char * symbol)
  * dlerror() the MacOS X version of the FreeBSD dlopen() interface.
  */
 char *
-dlerror (void)
+iodbc_dlerror (void)
 {
   const char *p;
 
@@ -1292,7 +1315,7 @@ dlerror (void)
  * dlclose() the MacOS X version of the FreeBSD dlopen() interface.
  */
 int
-dlclose (void * handle)
+iodbc_dlclose (void * handle)
 {
   struct dlopen_handle *p, *q;
   unsigned long options;
